@@ -14,9 +14,6 @@ const (
 	DefaultCommand = ""
 )
 
-// DefaultLogFile represents the default K9s log file.
-// var DefaultLogFile = filepath.Join(os.TempDir(), fmt.Sprintf("k9s-%s.log", MustK9sUser()))
-
 // Flags represents K9s configuration flags.
 type Flags struct {
 	RefreshRate   *int
@@ -29,6 +26,7 @@ type Flags struct {
 	ReadOnly      *bool
 	Write         *bool
 	Crumbsless    *bool
+	Splashless    *bool
 	ScreenDumpDir *string
 }
 
@@ -45,6 +43,7 @@ func NewFlags() *Flags {
 		ReadOnly:      boolPtr(false),
 		Write:         boolPtr(false),
 		Crumbsless:    boolPtr(false),
+		Splashless:    boolPtr(false),
 		ScreenDumpDir: strPtr(AppDumpsDir),
 	}
 }
