@@ -8,6 +8,7 @@ import (
 	"strconv"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"helm.sh/helm/v3/pkg/release"
@@ -24,6 +25,8 @@ func (Chart) IsGeneric() bool {
 	return false
 }
 
+func (Chart) SetViewSetting(*config.ViewSetting) {}
+
 // ColorerFunc colors a resource row.
 func (Chart) ColorerFunc() model1.ColorerFunc {
 	return model1.DefaultColorer
@@ -38,13 +41,13 @@ func (Chart) Header(_ string) model1.Header {
 		model1.HeaderColumn{Name: "STATUS"},
 		model1.HeaderColumn{Name: "CHART"},
 		model1.HeaderColumn{Name: "APP VERSION"},
-		model1.HeaderColumn{Name: "VALID", Wide: true},
-		model1.HeaderColumn{Name: "AGE", Time: true},
+		model1.HeaderColumn{Name: "VALID", Attrs: model1.Attrs{Wide: true}},
+		model1.HeaderColumn{Name: "AGE", Attrs: model1.Attrs{Time: true}},
 	}
 }
 
 // Render renders a chart to screen.
-func (c Chart) Render(o interface{}, ns string, r *model1.Row) error {
+func (c Chart) Render(o any, _ string, r *model1.Row) error {
 	h, ok := o.(ReleaseRes)
 	if !ok {
 		return fmt.Errorf("expected ReleaseRes, but got %T", o)
@@ -65,7 +68,7 @@ func (c Chart) Render(o interface{}, ns string, r *model1.Row) error {
 	return nil
 }
 
-func (c Chart) diagnose(s string) error {
+func (Chart) diagnose(s string) error {
 	if s != "deployed" {
 		return fmt.Errorf("chart is in an invalid state")
 	}
@@ -76,7 +79,7 @@ func (c Chart) diagnose(s string) error {
 // ----------------------------------------------------------------------------
 // Helpers...
 
-// ReleaseRes represents an helm chart resource.
+// ReleaseRes represents a helm chart resource.
 type ReleaseRes struct {
 	Release *release.Release
 }
