@@ -12,6 +12,7 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/model1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -49,11 +50,11 @@ type Tabular interface {
 	// SetInstance sets parent resource path.
 	SetInstance(string)
 
-	// SetLabelFilter sets the label filter.
-	SetLabelFilter(string)
+	// SetLabelSelector sets the label selector.
+	SetLabelSelector(labels.Selector)
 
-	// GetLabelFilter fetch the label filter.
-	GetLabelFilter() string
+	// GetLabelSelector fetch the label filter.
+	GetLabelSelector() labels.Selector
 
 	// Empty returns true if model has no data.
 	Empty() bool
