@@ -466,7 +466,7 @@ func (a *App) switchContext(ci *cmd.Interpreter, force bool) error {
 		p := cmd.NewInterpreter(a.Config.ActiveView())
 		p.ResetContextArg()
 		if p.IsContextCmd() {
-			a.Config.SetActiveView("pod")
+			a.Config.SetActiveView(client.PodGVR.String())
 		}
 		ns := a.Config.ActiveNamespace()
 		if !a.Conn().IsValidNamespace(ns) {
