@@ -18,7 +18,7 @@ type Rbac struct {
 }
 
 // NewRbac returns a new viewer.
-func NewRbac(gvr client.GVR) ResourceViewer {
+func NewRbac(gvr *client.GVR) ResourceViewer {
 	r := Rbac{
 		ResourceViewer: NewBrowser(gvr),
 	}
@@ -34,8 +34,8 @@ func (r *Rbac) bindKeys(aa *ui.KeyActions) {
 	aa.Add(ui.KeyShiftA, ui.NewKeyAction("Sort API-Group", r.GetTable().SortColCmd("API-GROUP", true), false))
 }
 
-func showRules(app *App, _ ui.Tabular, gvr client.GVR, path string) {
-	v := NewRbac(client.NewGVR("rbac"))
+func showRules(app *App, _ ui.Tabular, gvr *client.GVR, path string) {
+	v := NewRbac(client.RbacGVR)
 	v.SetContextFn(rbacCtx(gvr, path))
 
 	if err := app.inject(v, false); err != nil {
@@ -43,11 +43,11 @@ func showRules(app *App, _ ui.Tabular, gvr client.GVR, path string) {
 	}
 }
 
-func rbacCtx(gvr client.GVR, path string) ContextFunc {
+func rbacCtx(gvr *client.GVR, path string) ContextFunc {
 	return func(ctx context.Context) context.Context {
 		ctx = context.WithValue(ctx, internal.KeyPath, path)
 		return context.WithValue(ctx, internal.KeyGVR, gvr)
 	}
 }
 
-func blankEnterFn(_ *App, _ ui.Tabular, _ client.GVR, _ string) {}
+func blankEnterFn(_ *App, _ ui.Tabular, _ *client.GVR, _ string) {}
